<?php
/* Miranda Translator (SQLite Database Driver)
 * Copyright(C) 2004, 2005 Studio KUMA
 * 
 * This software is released under the terms and conditions of the GPL License V2.
 * For full license details, please refer to http://www.gnu.org/licenses/gpl.txt.
 *
 * Written by Stark Wong. Contact: starkwong@hotmail.com (E-mail and MSN)
 *
 * 2005/2/5 	V1.11	Added $like to select function, added parseCriteriaLike()
 */

require ('base.inc.php');

class SQLiteDatabaseA extends BaseDB {
	function SQLiteDatabaseA($conf) {
		$error='';
		$this->_conn=new SQLiteDatabase($conf['database'],0666,$error);

		$this->checkTables();
		
		$this->phraseUID=0;
		if ($error) ShowError("{$GLOBALS['rc']['db_noinit']} ($error)");
	}
	
	/* Basic Query Functions */
	
	function select($fields, $table, $criteria=NULL, $and=true, $suffix='', $nofetch=false, $like=false) {
		$query="SELECT ";
		if (is_array($fields)) {
			$query.=implode(",",$fields);
		} else
			$query.=$fields;
		
		if ($criteria && !is_array($criteria)) ShowError("Fix your script!");
		
		$query.=" FROM ".$this->getColumn($table).$this->parseCriteria($criteria,$and,$like)." $suffix";
		
		//echo "$query<br>";
		if ($nofetch) {
			return $this->execute($query);
		} else
			return $this->fetch($this->execute($query));
	}
	
	function execute($query) {
		$this->test();
		//echo "$query<br>";
		return $this->_conn->unbufferedQuery($query);
	}
	
	function fetch($result,$keep=false) {
		if ($result) {
			return $result->fetchAll(SQLITE_ASSOC);
		} else
			return false;		
	}
	
	function parseCriteria($criteria,$and,$like=false) {
		if (!$criteria) return "";
		if ($criteria && !is_array($criteria)) ShowError("Fix your script!");
		
		foreach (array_keys($criteria) as $key)
			$criteria[$key]=$this->getColumn($key).($like?" LIKE '":"='").$this->fixString($criteria[$key])."'";
		
		return " WHERE ".implode($and?' AND ':' OR ',$criteria);
	}
	
	function insert($table, $pairs) {
		$query="INSERT INTO $table";
		$keys=array_keys($pairs);
		if ($keys[0]!="0") {
			// Keyed array
			$query.=' ('.implode(',',$keys).')';
		}
		
		$query.=" VALUES ('";
		
		foreach ($keys as $key)
			$pairs[$key]=$this->fixString($pairs[$key]);
			
		$values=array_values($pairs);
		$query.=implode("','",$values);
		$query.="')";
		//echo "$query\n<br/>";
		return $this->execute($query);
	}
	
	function getColumn($str) {
		return "$str";
	}
	
	function close() {
		$this->test();
	}

	/* MT Functions */
	
	function checkTables() {
		global $rc;
		 
		$r=$this->execute("PRAGMA table_info(temp_phrasesheet)");
		if (!$r->valid())
			if (!$this->execute("CREATE TABLE temp_phrasesheet (seq INTEGER PRIMARY KEY, key BLOB NOT NULL UNIQUE, value BLOB NULL)")) ShowError($rc['db_notp']);
		
		$r=$this->execute("PRAGMA table_info(phrases)");
		if (!$r->valid())
			if (!$this->execute("CREATE TABLE phrases (seq INTEGER PRIMARY KEY, phrase BLOB NOT NULL UNIQUE, value BLOB NOT NULL)")) ShowError($rc['db_nop']);

		$r=$this->execute("PRAGMA table_info(ignoredphrases)");
		if (!$r->valid())
			if (!$this->execute("CREATE TABLE ignoredphrases (seq INTEGER PRIMARY KEY, phrase BLOB NOT NULL UNIQUE)")) ShowError($rc['db_noip']);		
		
	}
	
	function putTempPhrase($phrase) {
		$r=$this->select(array('key'),'temp_phrasesheet',array('key'=>$phrase),NULL,NULL,true);
		if ($r->valid())
			return false;
		else
			return $this->insert('temp_phrasesheet',array('key'=>$phrase));
	}
	
	function clearTempPhrases() {
		return $this->delete('temp_phrasesheet');
	}
	
	function putPhrase($phrase, $value) {
		$r=$this->select(array('phrase'),'phrases',array('phrase'=>$phrase),NULL,NULL,true);
		if ($r->valid())
			return false;
		else
			return $this->insert('phrases',array('phrase'=>$phrase,'value'=>$value));
	}

	function putIgnorePhrase($phrase) {
		$r=$this->select(array('phrase'),'ignoredphrases',array('phrase'=>$phrase),NULL,NULL,true);
		if ($r->valid())
			return false;
		else
			return $this->insert('ignoredphrases',array('phrase'=>$phrase));
	}
	
	function isIgnoredPhrase($phrase) {
		$result=$this->select(array('phrase'),'ignoredphrases',array('phrase'=>$phrase),NULL,NULL,true);
		if (!$result) {
			return false;
		} else {
			if ($result->valid()) {
				return true;
			} else {
				return false;
			}
		}
	}

	function getVersionString() {
		return $GLOBALS['rc']['db_sqver'].sqlite_libversion();
	}
	
	function fixString($in) {
		// Fix '
		$out=str_replace("'","''",rtrim($in,"\n\r"));
		
		return $out;
	}
	
	function unfixString($in) {
		// Fix '
		$out=str_replace("''","'",$in);
	
		return $out;
	
	} 
}

$dbclass="SQLiteDatabaseA";
?>
